using System;
using System.Web.UI;
using Telerik.Web.UI;
using System.Web.UI.WebControls;
using System.Collections.Generic;


namespace Telerik.Web.Examples.Scheduler.XmlSchedulerProviderExample
{
    public partial class DefaultCS : System.Web.UI.Page
    {
        private const string ProviderSessionKey = "Telerik.Web.Examples.Scheduler.XmlSchedulerProvider.DefaultCS";

		// You can safely ignore this method.
		// Its purpose is to limit the changes to the underlying data only to the active user session.
		protected void Page_Init(object sender, EventArgs e)
		{
			XmlSchedulerProvider provider;
			if ((Session[ProviderSessionKey] == null) || (!IsPostBack))
			{
				provider = new XmlSchedulerProvider(Server.MapPath("~/App_Data/WeatherAppointments.xml"), false);
				Session[ProviderSessionKey] = provider;
			}
			else
			{
				provider = (XmlSchedulerProvider)Session[ProviderSessionKey];
			}

			RadScheduler1.Provider = provider;
          
		}

        protected void RadScheduler1_TimeSlotCreated(object sender, TimeSlotCreatedEventArgs e)
        {
            RadScheduler scheduler = (RadScheduler)sender;
            if (scheduler.SelectedView == SchedulerViewType.WeekView || scheduler.SelectedView == SchedulerViewType.DayView)
            {
                if (e.TimeSlot.Start.Hour < scheduler.WorkDayStartTime.Hours || e.TimeSlot.Start.Hour >= scheduler.WorkDayEndTime.Hours)
                {
                    
                }
                else if (e.TimeSlot.Start.Hour >= 12 && e.TimeSlot.Start.Hour < 14)
                    {
                        //Set the CssClass property to visually distinguish your special days.
                        e.TimeSlot.CssClass = "Disabled";
                    }
            }
            if (scheduler.SelectedView == SchedulerViewType.MonthView)
            {
                if (scheduler.SelectedDate == e.TimeSlot.Start)
                {
                    e.TimeSlot.CssClass = "Christmas";
                }
                //Set the background-color of the slot
                bool createdWeatherAppointment = false;
                if (dict.ContainsKey(e.TimeSlot.Start.Date))
                {
                    e.TimeSlot.CssClass = dict[e.TimeSlot.Start.Date];
                    createdWeatherAppointment = true;
                }

                double duration = 0;
                foreach (Appointment ap in scheduler.Appointments.GetAppointmentsInRange(e.TimeSlot.Start, e.TimeSlot.End))
                {
                    duration += ap.Duration.TotalMinutes;
                }
                e.TimeSlot.Control.Attributes.Add("title", "total duration-" + duration + " minutes");
                Label countLabel = new Label();
                int count = scheduler.Appointments.GetAppointmentsInRange(e.TimeSlot.Start, e.TimeSlot.End).Count;
                if (createdWeatherAppointment)
                {
                    count--;
                }
                //e.TimeSlot.Appointments returns only visible appointments, so we cannot use it to get the total count for a day
                countLabel.Text = "appointments-" + count;
                countLabel.CssClass = "FloatRight";
                e.TimeSlot.Control.Controls.AddAt(4, countLabel);
            }


        }




        protected void RadScheduler1_AppointmentUpdate(object sender, AppointmentUpdateEventArgs e)
        {
            RadScheduler scheduler = (RadScheduler)sender;
            if (e.ModifiedAppointment.Start.Hour < scheduler.WorkDayStartTime.Hours || e.ModifiedAppointment.Start.Hour >= scheduler.WorkDayEndTime.Hours)
            {
                e.Cancel = true;
                ScriptManager.RegisterStartupScript(Page, GetType(), "alert", "alert('The duration of appointment overlaps Special Timeslot!');", true);
            }
            else if (e.ModifiedAppointment.Start.Hour >= 12 && e.ModifiedAppointment.Start.Hour<14)
                {
                    e.Cancel = true;
                    ScriptManager.RegisterStartupScript(Page, GetType(), "alert", "alert('The duration of appointment overlaps Special Timeslot!');", true);
                }
            
        }


        protected void RadScheduler1_TimeSlotContextMenuItemClicking(object sender, TimeSlotContextMenuItemClickingEventArgs e)
        {
            foreach (Appointment appt in e.TimeSlot.Appointments)
            {
                if (!String.IsNullOrEmpty(appt.Attributes["Weather"]))
                {
                    RadScheduler1.DeleteAppointment(appt, false);
                }
            }
            Appointment weatherAppointment = new Appointment();
            weatherAppointment.Start = e.TimeSlot.Start;
            weatherAppointment.End = e.TimeSlot.Start;

            switch (e.MenuItem.Value)
            {
                case "Sunny":
                    weatherAppointment.Attributes.Add("Weather", "Sunny");
                    break;
                case "Cloudy":
                    weatherAppointment.Attributes.Add("Weather", "Cloudy");
                    break;
                case "Rainy":
                    weatherAppointment.Attributes.Add("Weather", "Rainy");
                    break;
                case "Snowy":
                    weatherAppointment.Attributes.Add("Weather", "Snowy");
                    break;
                case "Remove":
                    weatherAppointment.Attributes.Add("Weather", "Remove");
                    break;
            }
            if (!String.IsNullOrEmpty(weatherAppointment.Attributes["Weather"]))
            {
                RadScheduler1.InsertAppointment(weatherAppointment);
                RadScheduler1.Rebind();
            }

        }
        Dictionary<DateTime, string> dict = new System.Collections.Generic.Dictionary<DateTime, string>();
        protected void RadScheduler1_AppointmentDataBound(object sender, SchedulerEventArgs e)
        {
            if (!String.IsNullOrEmpty(e.Appointment.Attributes["Weather"]))
            {
                if (!dict.ContainsKey(e.Appointment.Start.Date))
                {
                    dict.Add(e.Appointment.Start.Date, e.Appointment.Attributes["Weather"]);
                    //

                }
                else
                {
                    dict[e.Appointment.Start.Date] = e.Appointment.Attributes["Weather"];
                }
                e.Appointment.Visible = false;
            }
        }

        protected void RadScheduler1_PreRender(object sender, EventArgs e)
        {
            RadMenuItem menuItem3 = RadScheduler1.TimeSlotContextMenus[0].Items[3];
            RadMenuItem menuItem4 = RadScheduler1.TimeSlotContextMenus[0].Items[5];
            if (RadScheduler1.SelectedView!=SchedulerViewType.MonthView)
            {
                menuItem3.Visible = false;
                menuItem4.Visible = false;
                RadScheduler1.NumberOfHoveredRows = 1;
            }
            else
            {
                menuItem3.Visible = true;
                menuItem4.Visible = true;
                RadScheduler1.NumberOfHoveredRows = 0;
            }
            base.OnPreRender(e);
        }
}
}